dk.command "start", "drumkit start [env] :: Starts the DrumKit app in your current working directory.", (opts) ->
  if opts.env && opts.env != "development"
    dk.boot()
  else
    delete dk # reduce memory usage of parent
    util  = require('util')
    spawn = require('child_process').spawn
    child = spawn 'runjs', ["app.js"]

    child.stdout.on 'data', (data) ->
      process.stdout.write data.toString()

    child.stderr.on 'data', (data) ->
      process.stdout.write data.toString()

    child.on 'exit', (code) ->
      console.log "Drumkit died with code #{code}"
      process.exit()

dk.command "console", "drumkit console [env] :: Starts a CoffeeScript console with your app preloaded.", (opts) ->
  delete dk # reduce memory usage of parent
  console.log "Starting the console..."

  dk_env = opts[0] || "development"
  env = process.env
  env.DK_ENV = dk_env

  spawn = require("child_process").spawn
  child = spawn "coffee", ["-r", "#{__dirname}/console.coffee"], cwd: process.cwd(), env: env

  child.stdin.resume()
  child.stdout.on "data", (data) ->
    process.stdout.write data.toString()
  child.stderr.on "data", (data) ->
    process.stdout.write data.toString()

  process.stdin.resume()
  process.stdin.setEncoding 'utf8'
  process.stdin.on "data", (data) ->
    child.stdin.write data

  process.on "SIGINT", ->
    console.log "\nExiting console...\n"
    process.exit()

dk.command "consolejs", "drumkit consolejs [env] :: Starts a JS console with your app preloaded.", (opts) ->
  console.log "Starting the console..."
  repl = require 'repl'
  dk.env = opts[0] || "development"
  dk.loadModules()
  dk.config()
  dk.server.config port: null
  dk.websockets?.config run: false
  dk.run()

  con = repl.start()
  con.context.dk = dk
  
  # auto-load models
  # for name, klass of dk.model.allModels
  #   con.context[name] = klass

dk.command "plugin", "drumkit plugin pluginName :: Bootstraps a new DrumKit plugin at ./plugins/pluginName.", (opts) ->
  fs = require "fs"
  exec = require("child_process").exec
  pluginName = opts[0]
  templateDir = "#{fs.realpathSync(__dirname)}/../plugin-template"
  pluginsDir = "#{process.cwd()}/plugins"
  newDir = "#{pluginsDir}/#{pluginName}"
  command = "mkdir -p #{pluginsDir}; cp -R #{templateDir} #{newDir}"

  exec command, (error, stdout, stderr) ->
    console.log stdout
    if error
      console.log "Error creating your #{pluginName} plugin:", stderr
    else
      console.log """
        Successfully created plugins/#{pluginName}!
        Next you should:
          1. Update plugins/#{pluginName}/package.json with your plugin's information
          2. Add your plugin code to plugins/#{pluginName}/lib/plugin.coffee
          3. Add plugin commands to plugins/#{pluginName}/lib/commands.coffee
      """
